<?php
session_start(); // Start session

// Include the database connection
include 'mysql_connect.php';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Get and sanitize form data
    $username = mysqli_real_escape_string($conn, trim($_POST['username']));
    $password = mysqli_real_escape_string($conn, trim($_POST['password']));

    // Query to check username and hashed password
    $query = "SELECT username, is_admin FROM users WHERE username = ? AND password = SHA2(?, 256)";
     // Reference for prepare: https://www.php.net/manual/en/mysqli.prepare.php
    $stmt = $conn->prepare($query);
    //secure execution of parameterized queries: https://www.php.net/manual/en/mysqli.prepare.php
    $stmt->bind_param("ss", $username, $password);
    // Execute the prepared statement: https://www.php.net/manual/en/mysqli-stmt.execute.php
    $stmt->execute();
    // Get the result of the query: https://www.php.net/manual/en/mysqli-stmt.get-result.php
    $result = $stmt->get_result();
    // Check if exactly one row matches the query: https://www.php.net/manual/en/mysqli-result.num-rows.php
    if ($result->num_rows == 1) { // If a match is found
        // Fetch the result row as an associative array: https://www.php.net/manual/en/mysqli-result.fetch-assoc.php
        $user = $result->fetch_assoc();

        // Set session variables
        $_SESSION['username'] = $user['username'];
        $_SESSION['is_admin'] = $user['is_admin']; // Ensure this field exists in the database

        // Redirect based on user role
        if ($user['is_admin'] == 1) {
            header("Location: secret_page_admin.php");
        } else {
            header("Location: secret_page.php");
        }
        exit(); // Terminate script after redirection
    } else { // If no match is found
        header("Location: login_form.php?error=Invalid%20credentials");
        exit();
    }
} else {
    header("Location: login_form.php");
    exit();
}
?>
