<?php
session_start();
require 'mysql_connect.php'; // Main database connection
require 'mysql_connect_classicmodels.php'; 

// Ensure user is logged in
if (!isset($_SESSION['username'])) {
    header("Location: login_form.php");
    exit();
}

// Redirect admins to the admin page
if (isset($_SESSION['is_admin']) && $_SESSION['is_admin'] == 1) {
    header("Location: secret_page_admin.php");
    exit();
}

$username = $_SESSION['username'];

// Fetch all user details except sensitive ones like passwords
$query = "SELECT id, username, email, firstname, lastname FROM users WHERE username = ?";
// Using prepared statements for security: https://www.php.net/manual/en/mysqli.prepare.php
$stmt = $conn->prepare($query);
$stmt->bind_param("s", $username);
$stmt->execute();
$result = $stmt->get_result();
// Fetch a single result row as an associative array: https://www.php.net/manual/en/mysqli-result.fetch-assoc.php
$user = $result->fetch_assoc();
?>

<!DOCTYPE html>
<html>
<head>
    <title>User Secret Page</title>
</head>
<body>
    <h1>Welcome, <?php echo htmlspecialchars($user['firstname']); ?>!</h1>
    <p><strong>Your Details:</strong></p>
    <ul>
        <li><strong>ID:</strong> <?php echo htmlspecialchars($user['id']); ?></li>
        <li><strong>Username:</strong> <?php echo htmlspecialchars($user['username']); ?></li>
        <li><strong>Email:</strong> <?php echo htmlspecialchars($user['email']); ?></li>
        <li><strong>First Name:</strong> <?php echo htmlspecialchars($user['firstname']); ?></li>
        <li><strong>Last Name:</strong> <?php echo htmlspecialchars($user['lastname']); ?></li>
        
    </ul>
    <p><?php echo htmlspecialchars($user['firstname']); ?>'s account has a balance of $2,000.00.</p><br

    <hr>

    <p><strong>Search for products below:</strong></p>

    <!-- Product Search Form -->
    <form method="POST" action="">
        <label for="productName">Product Name:</label>
        <input type="text" id="productName" name="productName"><br><br>

        <label for="productDescription">Product Description:</label>
        <input type="text" id="productDescription" name="productDescription"><br><br>

        <label for="minPrice">Minimum Price:</label>
        <input type="number" id="minPrice" name="minPrice" step="0.01"><br><br>

        <label for="maxPrice">Maximum Price:</label>
        <input type="number" id="maxPrice" name="maxPrice" step="0.01"><br><br>

        <button type="submit">Search</button>
    </form><br>

    <?php
    // Handle search and display results
    if ($_SERVER['REQUEST_METHOD'] === 'POST') {
        $productName = $_POST['productName'] ?? '';
        $productDescription = $_POST['productDescription'] ?? '';
        $minPrice = $_POST['minPrice'] ?? 0;
        $maxPrice = $_POST['maxPrice'] ?? 999999;

        // Construct the query
        $searchQuery = "SELECT productName, productDescription, MSRP FROM products WHERE 1=1";
        $params = [];
        $types = "";

        if (!empty($productName)) {
            $searchQuery .= " AND productName LIKE ?";
            $params[] = "%" . $productName . "%";
            $types .= "s";
        }
        if (!empty($productDescription)) {
            $searchQuery .= " AND productDescription LIKE ?";
            $params[] = "%" . $productDescription . "%";
            $types .= "s";
        }
        if (!empty($minPrice)) {
            $searchQuery .= " AND MSRP >= ?";
            $params[] = $minPrice;
            $types .= "d";
        }
        if (!empty($maxPrice)) {
            $searchQuery .= " AND MSRP <= ?";
            $params[] = $maxPrice;
            $types .= "d";
        }

        $stmt = $classicmodels_conn->prepare($searchQuery);
        if ($types) {
             // Reference for unpacking parameters with spread operator: https://www.php.net/manual/en/migration56.new-features.php#migration56.new-features.spread
            $stmt->bind_param($types, ...$params);
        }
        $stmt->execute();
        // Retrieve the result set from the query: https://www.php.net/manual/en/mysqli-stmt.get-result.php
        $result = $stmt->get_result();

        echo "<h2>Search Results:</h2>";
         // Reference: https://www.php.net/manual/en/mysqli-result.num-rows.php
        if ($result->num_rows > 0) {
            echo "<table border='1' cellpadding='5' cellspacing='0' style='width: 100%; text-align: left;'>
                    <tr>
                        <th>Product Name</th>
                        <th>Product Description</th>
                        <th>Price (MSRP)</th>
                    </tr>";
            // Fetch rows as associative arrays: Reference for fetch_assoc: https://www.php.net/manual/en/mysqli-result.fetch-assoc.php
            while ($row = $result->fetch_assoc()) {
                echo "<tr>
                 <!-- Reference for number_format: https://www.php.net/manual/en/function.number-format.php -->
                        <td>" . htmlspecialchars($row['productName']) . "</td>
                        <td>" . htmlspecialchars($row['productDescription']) . "</td>
                        <td>$" . number_format($row['MSRP'], 2) . "</td>
                    </tr>";
                   
            }
            echo "</table>";
        } else {
            echo "<p>No products found.</p>";
        }
    }
    ?>

    <form action="logout.php" method="post">
        <button type="submit">Log Out</button>
    </form>
</body>
</html>
